# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBetaCapabilityUserInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_at': 'datetime',
        'plan_id': 'str',
        'removed_at': 'datetime',
        'approved_at': 'datetime',
        'capability_state': 'int',
        'source': 'int',
        'email': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'is_guest': 'bool',
        'is_light': 'bool',
        'company': 'BTCompanySummaryInfo',
        'global_permissions': 'GlobalPermissionInfo',
        'last_login_time': 'datetime',
        'state': 'int',
        'image': 'str',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'plan_id': 'planId',
        'removed_at': 'removedAt',
        'approved_at': 'approvedAt',
        'capability_state': 'capabilityState',
        'source': 'source',
        'email': 'email',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'is_guest': 'isGuest',
        'is_light': 'isLight',
        'company': 'company',
        'global_permissions': 'globalPermissions',
        'last_login_time': 'lastLoginTime',
        'state': 'state',
        'image': 'image',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, created_at=None, plan_id=None, removed_at=None, approved_at=None, capability_state=None, source=None, email=None, first_name=None, last_name=None, is_guest=None, is_light=None, company=None, global_permissions=None, last_login_time=None, state=None, image=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTBetaCapabilityUserInfo - a model defined in OpenAPI"""  # noqa: E501

        self._created_at = None
        self._plan_id = None
        self._removed_at = None
        self._approved_at = None
        self._capability_state = None
        self._source = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self._is_guest = None
        self._is_light = None
        self._company = None
        self._global_permissions = None
        self._last_login_time = None
        self._state = None
        self._image = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if plan_id is not None:
            self.plan_id = plan_id
        if removed_at is not None:
            self.removed_at = removed_at
        if approved_at is not None:
            self.approved_at = approved_at
        if capability_state is not None:
            self.capability_state = capability_state
        if source is not None:
            self.source = source
        if email is not None:
            self.email = email
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if is_guest is not None:
            self.is_guest = is_guest
        if is_light is not None:
            self.is_light = is_light
        if company is not None:
            self.company = company
        if global_permissions is not None:
            self.global_permissions = global_permissions
        if last_login_time is not None:
            self.last_login_time = last_login_time
        if state is not None:
            self.state = state
        if image is not None:
            self.image = image
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def created_at(self):
        """Gets the created_at of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The created_at of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTBetaCapabilityUserInfo.


        :param created_at: The created_at of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def plan_id(self):
        """Gets the plan_id of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The plan_id of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this BTBetaCapabilityUserInfo.


        :param plan_id: The plan_id of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: str
        """

        self._plan_id = plan_id

    @property
    def removed_at(self):
        """Gets the removed_at of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The removed_at of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._removed_at

    @removed_at.setter
    def removed_at(self, removed_at):
        """Sets the removed_at of this BTBetaCapabilityUserInfo.


        :param removed_at: The removed_at of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: datetime
        """

        self._removed_at = removed_at

    @property
    def approved_at(self):
        """Gets the approved_at of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The approved_at of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._approved_at

    @approved_at.setter
    def approved_at(self, approved_at):
        """Sets the approved_at of this BTBetaCapabilityUserInfo.


        :param approved_at: The approved_at of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: datetime
        """

        self._approved_at = approved_at

    @property
    def capability_state(self):
        """Gets the capability_state of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The capability_state of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: int
        """
        return self._capability_state

    @capability_state.setter
    def capability_state(self, capability_state):
        """Sets the capability_state of this BTBetaCapabilityUserInfo.


        :param capability_state: The capability_state of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: int
        """

        self._capability_state = capability_state

    @property
    def source(self):
        """Gets the source of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The source of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: int
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this BTBetaCapabilityUserInfo.


        :param source: The source of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: int
        """

        self._source = source

    @property
    def email(self):
        """Gets the email of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The email of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BTBetaCapabilityUserInfo.


        :param email: The email of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """Gets the first_name of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The first_name of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this BTBetaCapabilityUserInfo.


        :param first_name: The first_name of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The last_name of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this BTBetaCapabilityUserInfo.


        :param last_name: The last_name of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def is_guest(self):
        """Gets the is_guest of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The is_guest of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_guest

    @is_guest.setter
    def is_guest(self, is_guest):
        """Sets the is_guest of this BTBetaCapabilityUserInfo.


        :param is_guest: The is_guest of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: bool
        """

        self._is_guest = is_guest

    @property
    def is_light(self):
        """Gets the is_light of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The is_light of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_light

    @is_light.setter
    def is_light(self, is_light):
        """Sets the is_light of this BTBetaCapabilityUserInfo.


        :param is_light: The is_light of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: bool
        """

        self._is_light = is_light

    @property
    def company(self):
        """Gets the company of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The company of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: BTCompanySummaryInfo
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this BTBetaCapabilityUserInfo.


        :param company: The company of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: BTCompanySummaryInfo
        """

        self._company = company

    @property
    def global_permissions(self):
        """Gets the global_permissions of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The global_permissions of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: GlobalPermissionInfo
        """
        return self._global_permissions

    @global_permissions.setter
    def global_permissions(self, global_permissions):
        """Sets the global_permissions of this BTBetaCapabilityUserInfo.


        :param global_permissions: The global_permissions of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: GlobalPermissionInfo
        """

        self._global_permissions = global_permissions

    @property
    def last_login_time(self):
        """Gets the last_login_time of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The last_login_time of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._last_login_time

    @last_login_time.setter
    def last_login_time(self, last_login_time):
        """Sets the last_login_time of this BTBetaCapabilityUserInfo.


        :param last_login_time: The last_login_time of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: datetime
        """

        self._last_login_time = last_login_time

    @property
    def state(self):
        """Gets the state of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The state of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTBetaCapabilityUserInfo.


        :param state: The state of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: int
        """

        self._state = state

    @property
    def image(self):
        """Gets the image of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The image of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this BTBetaCapabilityUserInfo.


        :param image: The image of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def name(self):
        """Gets the name of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The name of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTBetaCapabilityUserInfo.


        :param name: The name of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The id of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTBetaCapabilityUserInfo.


        :param id: The id of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The href of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTBetaCapabilityUserInfo.


        :param href: The href of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTBetaCapabilityUserInfo.  # noqa: E501


        :return: The view_ref of this BTBetaCapabilityUserInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTBetaCapabilityUserInfo.


        :param view_ref: The view_ref of this BTBetaCapabilityUserInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBetaCapabilityUserInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTReleasePackageWorkflowChangeParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'workspace_id': 'str',
        'release_package_id': 'str',
        'workflow_state': 'str',
        'is_obsoletion': 'bool',
        'version_id': 'str'
    }

    attribute_map = {
        'workspace_id': 'workspaceId',
        'release_package_id': 'releasePackageId',
        'workflow_state': 'workflowState',
        'is_obsoletion': 'isObsoletion',
        'version_id': 'versionId'
    }

    def __init__(self, workspace_id=None, release_package_id=None, workflow_state=None, is_obsoletion=None, version_id=None):  # noqa: E501
        """BTReleasePackageWorkflowChangeParams - a model defined in OpenAPI"""  # noqa: E501

        self._workspace_id = None
        self._release_package_id = None
        self._workflow_state = None
        self._is_obsoletion = None
        self._version_id = None
        self.discriminator = None

        if workspace_id is not None:
            self.workspace_id = workspace_id
        if release_package_id is not None:
            self.release_package_id = release_package_id
        if workflow_state is not None:
            self.workflow_state = workflow_state
        if is_obsoletion is not None:
            self.is_obsoletion = is_obsoletion
        if version_id is not None:
            self.version_id = version_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The workspace_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTReleasePackageWorkflowChangeParams.


        :param workspace_id: The workspace_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def release_package_id(self):
        """Gets the release_package_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The release_package_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: str
        """
        return self._release_package_id

    @release_package_id.setter
    def release_package_id(self, release_package_id):
        """Sets the release_package_id of this BTReleasePackageWorkflowChangeParams.


        :param release_package_id: The release_package_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: str
        """

        self._release_package_id = release_package_id

    @property
    def workflow_state(self):
        """Gets the workflow_state of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The workflow_state of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: str
        """
        return self._workflow_state

    @workflow_state.setter
    def workflow_state(self, workflow_state):
        """Sets the workflow_state of this BTReleasePackageWorkflowChangeParams.


        :param workflow_state: The workflow_state of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: str
        """

        self._workflow_state = workflow_state

    @property
    def is_obsoletion(self):
        """Gets the is_obsoletion of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The is_obsoletion of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_obsoletion

    @is_obsoletion.setter
    def is_obsoletion(self, is_obsoletion):
        """Sets the is_obsoletion of this BTReleasePackageWorkflowChangeParams.


        :param is_obsoletion: The is_obsoletion of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: bool
        """

        self._is_obsoletion = is_obsoletion

    @property
    def version_id(self):
        """Gets the version_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The version_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this BTReleasePackageWorkflowChangeParams.


        :param version_id: The version_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: str
        """

        self._version_id = version_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTReleasePackageWorkflowChangeParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Export a STEP file
"""

from onshape_client.client import Client
from onshape_client.onshape_url import OnshapeElement
from onshape_client.models.bt_translate_format_params import BTTranslateFormatParams
import time
import json
import os.path

client = Client()

# We're saving these files to the home directory ("~")
client.configuration.temp_folder_path = os.path.expanduser("~")

# Turn the URL into an "OnshapeElement"
url = "https://staging.dev.onshape.com/documents/85820308b21bc556da71354e/w/6e6f91f91d8bba3d8453de91/e/6155878d774398248dea31b9"
cube = OnshapeElement(url, client=client)

# Create the params. Note there are far more params that can be specified.
params = BTTranslateFormatParams(element_id=cube.eid, format_name="PDF", store_in_document=False)

# Call the client
response = client.drawings_api.translate_format4(cube.did, cube.wvm, cube.wvmid, cube.eid, bt_translate_format_params=params)

translation_id = response.id
state = response.request_state

# Long poll every 2 seconds until the translation is marked as done - alternatively you could submit a webhook
parsed_response = None
while state == 'ACTIVE':
    time.sleep(2)
    response = client.translation_api.get_translation(translation_id, _preload_content=False)
    parsed_response = json.loads(response.data.decode("UTF-8"))
    state = parsed_response["requestState"]

# Make the actual download when the translation is done, otherwise report the error
if state == "DONE":
    client.documents_api.download_external_data(cube.did, parsed_response["resultExternalDataIds"][0])
    print("File saved to " + client.configuration.temp_folder_path)
else:
    print("An error ocurred on the server! Here is the response: \n" + parsed_response)
"""
File saved to <temp_folder_path>
"""


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTPurchaseParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'password': 'str',
        'email': 'str',
        'plan_id': 'str',
        'seats': 'int',
        'domain_prefix': 'str',
        'payment_type': 'int',
        'user_id': 'str',
        'trial_period_days': 'int',
        'light_seats': 'int',
        'allow_deprecated_plan': 'bool',
        'ref_id': 'str',
        'reseller_name': 'str'
    }

    attribute_map = {
        'password': 'password',
        'email': 'email',
        'plan_id': 'planId',
        'seats': 'seats',
        'domain_prefix': 'domainPrefix',
        'payment_type': 'paymentType',
        'user_id': 'userId',
        'trial_period_days': 'trialPeriodDays',
        'light_seats': 'lightSeats',
        'allow_deprecated_plan': 'allowDeprecatedPlan',
        'ref_id': 'refId',
        'reseller_name': 'resellerName'
    }

    def __init__(self, password=None, email=None, plan_id=None, seats=None, domain_prefix=None, payment_type=None, user_id=None, trial_period_days=None, light_seats=None, allow_deprecated_plan=None, ref_id=None, reseller_name=None):  # noqa: E501
        """BTPurchaseParams - a model defined in OpenAPI"""  # noqa: E501

        self._password = None
        self._email = None
        self._plan_id = None
        self._seats = None
        self._domain_prefix = None
        self._payment_type = None
        self._user_id = None
        self._trial_period_days = None
        self._light_seats = None
        self._allow_deprecated_plan = None
        self._ref_id = None
        self._reseller_name = None
        self.discriminator = None

        if password is not None:
            self.password = password
        if email is not None:
            self.email = email
        if plan_id is not None:
            self.plan_id = plan_id
        if seats is not None:
            self.seats = seats
        if domain_prefix is not None:
            self.domain_prefix = domain_prefix
        if payment_type is not None:
            self.payment_type = payment_type
        if user_id is not None:
            self.user_id = user_id
        if trial_period_days is not None:
            self.trial_period_days = trial_period_days
        if light_seats is not None:
            self.light_seats = light_seats
        if allow_deprecated_plan is not None:
            self.allow_deprecated_plan = allow_deprecated_plan
        if ref_id is not None:
            self.ref_id = ref_id
        if reseller_name is not None:
            self.reseller_name = reseller_name

    @property
    def password(self):
        """Gets the password of this BTPurchaseParams.  # noqa: E501


        :return: The password of this BTPurchaseParams.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this BTPurchaseParams.


        :param password: The password of this BTPurchaseParams.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def email(self):
        """Gets the email of this BTPurchaseParams.  # noqa: E501


        :return: The email of this BTPurchaseParams.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BTPurchaseParams.


        :param email: The email of this BTPurchaseParams.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def plan_id(self):
        """Gets the plan_id of this BTPurchaseParams.  # noqa: E501


        :return: The plan_id of this BTPurchaseParams.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this BTPurchaseParams.


        :param plan_id: The plan_id of this BTPurchaseParams.  # noqa: E501
        :type: str
        """

        self._plan_id = plan_id

    @property
    def seats(self):
        """Gets the seats of this BTPurchaseParams.  # noqa: E501


        :return: The seats of this BTPurchaseParams.  # noqa: E501
        :rtype: int
        """
        return self._seats

    @seats.setter
    def seats(self, seats):
        """Sets the seats of this BTPurchaseParams.


        :param seats: The seats of this BTPurchaseParams.  # noqa: E501
        :type: int
        """

        self._seats = seats

    @property
    def domain_prefix(self):
        """Gets the domain_prefix of this BTPurchaseParams.  # noqa: E501


        :return: The domain_prefix of this BTPurchaseParams.  # noqa: E501
        :rtype: str
        """
        return self._domain_prefix

    @domain_prefix.setter
    def domain_prefix(self, domain_prefix):
        """Sets the domain_prefix of this BTPurchaseParams.


        :param domain_prefix: The domain_prefix of this BTPurchaseParams.  # noqa: E501
        :type: str
        """

        self._domain_prefix = domain_prefix

    @property
    def payment_type(self):
        """Gets the payment_type of this BTPurchaseParams.  # noqa: E501


        :return: The payment_type of this BTPurchaseParams.  # noqa: E501
        :rtype: int
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """Sets the payment_type of this BTPurchaseParams.


        :param payment_type: The payment_type of this BTPurchaseParams.  # noqa: E501
        :type: int
        """

        self._payment_type = payment_type

    @property
    def user_id(self):
        """Gets the user_id of this BTPurchaseParams.  # noqa: E501


        :return: The user_id of this BTPurchaseParams.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BTPurchaseParams.


        :param user_id: The user_id of this BTPurchaseParams.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def trial_period_days(self):
        """Gets the trial_period_days of this BTPurchaseParams.  # noqa: E501


        :return: The trial_period_days of this BTPurchaseParams.  # noqa: E501
        :rtype: int
        """
        return self._trial_period_days

    @trial_period_days.setter
    def trial_period_days(self, trial_period_days):
        """Sets the trial_period_days of this BTPurchaseParams.


        :param trial_period_days: The trial_period_days of this BTPurchaseParams.  # noqa: E501
        :type: int
        """

        self._trial_period_days = trial_period_days

    @property
    def light_seats(self):
        """Gets the light_seats of this BTPurchaseParams.  # noqa: E501


        :return: The light_seats of this BTPurchaseParams.  # noqa: E501
        :rtype: int
        """
        return self._light_seats

    @light_seats.setter
    def light_seats(self, light_seats):
        """Sets the light_seats of this BTPurchaseParams.


        :param light_seats: The light_seats of this BTPurchaseParams.  # noqa: E501
        :type: int
        """

        self._light_seats = light_seats

    @property
    def allow_deprecated_plan(self):
        """Gets the allow_deprecated_plan of this BTPurchaseParams.  # noqa: E501


        :return: The allow_deprecated_plan of this BTPurchaseParams.  # noqa: E501
        :rtype: bool
        """
        return self._allow_deprecated_plan

    @allow_deprecated_plan.setter
    def allow_deprecated_plan(self, allow_deprecated_plan):
        """Sets the allow_deprecated_plan of this BTPurchaseParams.


        :param allow_deprecated_plan: The allow_deprecated_plan of this BTPurchaseParams.  # noqa: E501
        :type: bool
        """

        self._allow_deprecated_plan = allow_deprecated_plan

    @property
    def ref_id(self):
        """Gets the ref_id of this BTPurchaseParams.  # noqa: E501


        :return: The ref_id of this BTPurchaseParams.  # noqa: E501
        :rtype: str
        """
        return self._ref_id

    @ref_id.setter
    def ref_id(self, ref_id):
        """Sets the ref_id of this BTPurchaseParams.


        :param ref_id: The ref_id of this BTPurchaseParams.  # noqa: E501
        :type: str
        """

        self._ref_id = ref_id

    @property
    def reseller_name(self):
        """Gets the reseller_name of this BTPurchaseParams.  # noqa: E501


        :return: The reseller_name of this BTPurchaseParams.  # noqa: E501
        :rtype: str
        """
        return self._reseller_name

    @reseller_name.setter
    def reseller_name(self, reseller_name):
        """Sets the reseller_name of this BTPurchaseParams.


        :param reseller_name: The reseller_name of this BTPurchaseParams.  # noqa: E501
        :type: str
        """

        self._reseller_name = reseller_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTPurchaseParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class IntegrationsParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'providers_type': 'int',
        'access_level': 'int',
        'team_ids': 'list[str]',
        'provider_ids': 'list[str]',
        'user_ids': 'list[str]'
    }

    attribute_map = {
        'providers_type': 'providersType',
        'access_level': 'accessLevel',
        'team_ids': 'teamIds',
        'provider_ids': 'providerIds',
        'user_ids': 'userIds'
    }

    def __init__(self, providers_type=None, access_level=None, team_ids=None, provider_ids=None, user_ids=None):  # noqa: E501
        """IntegrationsParams - a model defined in OpenAPI"""  # noqa: E501

        self._providers_type = None
        self._access_level = None
        self._team_ids = None
        self._provider_ids = None
        self._user_ids = None
        self.discriminator = None

        if providers_type is not None:
            self.providers_type = providers_type
        if access_level is not None:
            self.access_level = access_level
        if team_ids is not None:
            self.team_ids = team_ids
        if provider_ids is not None:
            self.provider_ids = provider_ids
        if user_ids is not None:
            self.user_ids = user_ids

    @property
    def providers_type(self):
        """Gets the providers_type of this IntegrationsParams.  # noqa: E501


        :return: The providers_type of this IntegrationsParams.  # noqa: E501
        :rtype: int
        """
        return self._providers_type

    @providers_type.setter
    def providers_type(self, providers_type):
        """Sets the providers_type of this IntegrationsParams.


        :param providers_type: The providers_type of this IntegrationsParams.  # noqa: E501
        :type: int
        """

        self._providers_type = providers_type

    @property
    def access_level(self):
        """Gets the access_level of this IntegrationsParams.  # noqa: E501


        :return: The access_level of this IntegrationsParams.  # noqa: E501
        :rtype: int
        """
        return self._access_level

    @access_level.setter
    def access_level(self, access_level):
        """Sets the access_level of this IntegrationsParams.


        :param access_level: The access_level of this IntegrationsParams.  # noqa: E501
        :type: int
        """

        self._access_level = access_level

    @property
    def team_ids(self):
        """Gets the team_ids of this IntegrationsParams.  # noqa: E501


        :return: The team_ids of this IntegrationsParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._team_ids

    @team_ids.setter
    def team_ids(self, team_ids):
        """Sets the team_ids of this IntegrationsParams.


        :param team_ids: The team_ids of this IntegrationsParams.  # noqa: E501
        :type: list[str]
        """

        self._team_ids = team_ids

    @property
    def provider_ids(self):
        """Gets the provider_ids of this IntegrationsParams.  # noqa: E501


        :return: The provider_ids of this IntegrationsParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._provider_ids

    @provider_ids.setter
    def provider_ids(self, provider_ids):
        """Sets the provider_ids of this IntegrationsParams.


        :param provider_ids: The provider_ids of this IntegrationsParams.  # noqa: E501
        :type: list[str]
        """

        self._provider_ids = provider_ids

    @property
    def user_ids(self):
        """Gets the user_ids of this IntegrationsParams.  # noqa: E501


        :return: The user_ids of this IntegrationsParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_ids

    @user_ids.setter
    def user_ids(self, user_ids):
        """Sets the user_ids of this IntegrationsParams.


        :param user_ids: The user_ids of this IntegrationsParams.  # noqa: E501
        :type: list[str]
        """

        self._user_ids = user_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegrationsParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""A collection of utility functions"""
import json
from onshape_client.client import Client
import os

def parse_quantity(q):
    """
    Parse an Onshape units definition
    Args:
        q:an Onshape units definition... for instance:
            {
              'typeTag': '',
              'unitToPower': [
                {
                  'key': 'METER',
                  'value': 1
                }
              ],
              'value': 0.0868175271040671
            }

    Returns:
        a string that can be converted to any other unit engine.

    >>> from onshape_client.utility import parse_quantity
    >>> d = {'value': 0.1414213562373095, 'unitToPower': [{'value': 1, 'key': 'METER'}], 'typeTag': ''}
    >>> parse_quantity(d)
    '0.1414213562373095*meter'

    >>> d = {'value': 0.1414213562373095, 'unitToPower': [{'value': 3, 'key': 'MILLIMETER'}], 'typeTag': ''}
    >>> parse_quantity(d)
    '0.1414213562373095*millimeter**3'
    """
    units_s = str(q['value'])
    for u in q['unitToPower']:
        units_s = units_s + "*" + u['key'].lower()
        power = u['value']
        if not power == 1:
            units_s = units_s + "**" + str(power)
    return units_s


def get_field(response, field):
    data = json.loads(response.data.decode("UTF-8"))
    return data[field]


def write_to_file(data_uri):
    """Write a data uri to a local file"""
    from base64 import b64decode
    import re

    header, encoded = data_uri.split(",", 1)
    data = b64decode(encoded)
    pattern = re.compile(r"""name=([^;]*)""")
    name = pattern.search(header).groups()[0]
    name = name.replace("+", " ")
    tmp_path = "tmp/"
    try:
        os.mkdir(tmp_path)
    except BaseException:
        pass
    file_path = os.getcwd() + "/" + tmp_path + name
    with open(file_path, "wb") as f:
        f.write(data)

    return file_path


from onshape_client.client import Client
from onshape_client.onshape_url import OnshapeElement

import json
from onshape_client.compatible_imports import HTTPServer, HTTPHandler, sendable
import os
import urllib
import webbrowser
from onshape_client.example_programs.set_metadata import MetaDataBody
from onshape_client.example_programs.import_file import import_file
from onshape_client.utility import write_to_file, get_field
from onshape_client.models.bt_mass_prop_response import BTMassPropResponse
from onshape_client.models.bt_bounding_box import BTBoundingBox

client = Client()


class myHandler(HTTPHandler):
    def do_GET(self):

        try:
            # Say we are at an https port so that OAuth package doesn't complain. This isn't a security concern because
            # it is just so that the authorization code is correctly parsed.
            self.send_response(200)
            self.send_header('Content-type', 'text/html')
            self.end_headers()
            content = open(os.path.dirname(__file__) + "/assets/form.html", 'r').read()
            self.wfile.write(sendable(content))
        except BaseException as e:
            self.send_response(500)
            self.send_header('Content-type', 'text/html')
            self.end_headers()
            content = '''
                        <html><head><title>Error!</title></head>
                        <body><p>Something happened and here is what we know: {}</p>
                        <p>You may close this tab.</p>
                        </body></html>
                        '''.format(e)
            self.wfile.write(sendable(content))

    def do_POST(self):
        content_length = int(self.headers['Content-Length'])
        body = self.rfile.read(content_length)
        unquoted_s = urllib.unquote(body)
        data = json.loads(unquoted_s)

        from onshape_client.models import BTDocumentParams
        bt_document_params = BTDocumentParams(name=data["doc_name"])
        new_doc_response = client.documents_api.create11(bt_document_params, _preload_content=False)
        did = get_field(new_doc_response, "id")
        wid = get_field(new_doc_response, "defaultWorkspace")["id"]
        # Use a fake eid because it isn't used later.
        eid = "00000000000000"
        self.onshape_element = OnshapeElement.create_from_ids(did, "w", wid, eid)

        if "import_items" in data:
            for import_item in data["import_items"]:
                self.import_item(import_item)

        self.send_response(200)
        self.send_header('Content-type', 'application/json')
        self.send_header('Access-Control-Allow-Origin', '*')
        self.end_headers()
        content = {"document_href": self.onshape_element.get_url(url_type="document")}
        self.wfile.write(sendable(json.dumps(content)))

    def import_item(self, import_item):
        did = self.onshape_element.did
        wid = self.onshape_element.wvmid
        path = write_to_file(import_item["file"])
        eid = import_file(path, did, wid)
        onshape_element = self.onshape_element
        onshape_element.eid = eid
        url = onshape_element.get_url()
        mass_properties = client.part_studios_api.get_mass_properties(did, 'w', wid, eid) # type: BTMassPropResponse
        volume = mass_properties.bodies["-all-"].volume[0]*1000000000
        bounding_box = client.part_studios_api.get_bounding_boxes2(did, 'w', wid, eid, _preload_content=False)
        bounding_box = json.loads(bounding_box.data)
        x_span = (bounding_box["highX"]-bounding_box["lowX"])*1000
        y_span = (bounding_box["highY"]-bounding_box["lowY"])*1000
        z_span = (bounding_box["highZ"]-bounding_box["lowZ"])*1000
        bounding_box = "L = {x_span}, W = {y_span}, H = {z_span}".format(x_span=x_span, y_span=y_span, z_span=z_span)

        if "part_metadata" in import_item or "element_metadata" in import_item:
            meta_data_to_be_set = MetaDataBody(OnshapeElement.create_from_ids(did, "w", wid, eid))
            if "part_metadata" in import_item:
                part_metadata = import_item["part_metadata"]
                # Add the volume part volume property from the API:
                meta_data_to_be_set.add_to_part_metadata("Part Volume", volume)
                meta_data_to_be_set.add_to_part_metadata("Bounding Box", bounding_box)
                for k, v in part_metadata.items():
                    # For the fixed field items, set for the first part
                    if k != "additionalItems":
                        meta_data_to_be_set.add_to_part_metadata(k,
                                                                 v)
                    else:
                        for custom_metadata_item in v:
                                meta_data_to_be_set.add_to_part_metadata(custom_metadata_item["part_id"],
                                                                     custom_metadata_item["property_name"],
                                                                     custom_metadata_item["new_value"])
            if "element_metadata" in import_item:
                element_metadata = import_item["element_metadata"]
                for k, v in element_metadata.items():
                    if k != "additionalItems":
                        meta_data_to_be_set.add_to_element_metadata(k,v)
                    else:
                        for custom_metadata_item in v:
                            meta_data_to_be_set.add_to_element_metadata(custom_metadata_item["property_name"],
                                                                        custom_metadata_item["new_value"], eid=eid)
            meta_data_to_be_set.send()

        if "bounding_box" in import_item and import_item["bounding_box"]:
            feature_path = "bound_all_set_metadata.json"
            # feature_path = "bound_all_feature.json"
            # feature_path = "make_cube_feature.json"
            with open(os.path.dirname(__file__) + "/assets/" + feature_path, "r") as f:
                body = {"feature": json.loads(f.read())}
            client.part_studios_api.add_feature1(did, "w", wid, eid, body=body)


class MyServer(HTTPServer, object):

    def server_activate(self):
        super(MyServer, self).server_activate()
        webbrowser.open("{}:{}".format(self.server_address[0], self.server_port))


server = MyServer(('localhost', 9000), myHandler)
server.serve_forever()



"""For getting measurements defined by the custom "measure" feature: https://cad.onshape.com/documents/78aa66ffe6f1daceb9cfad3d/v/746f3ce1b31d39942593ed54/e/92549789b92e9aa35f676f4e

To fetch measurements from the API:

1. Make sure the desired geometry is defined using the feature within this document. The "use measurements variable" checkbox should be selected.
2. Call the Evaluate Featurescript API call with your client/code with the following script:

	function(context, queries) {
            return getVariable(context, "m");
        }

This will return all the variables defined under "m", ie, m.radius, m.my_custom_length, etc...
3. Now use the resulting map from measurements feature name to value within your code.
"""

from onshape_client.client import Client
from onshape_client.onshape_url import OnshapeElement
from onshape_client.models.bt_feature_script_eval_call import BTFeatureScriptEvalCall
from onshape_client.utility import parse_quantity
import json

script = \
    r"""
    function(context, queries) {
            return getVariable(context, "m");
        }
    """

element = OnshapeElement(
    "https://cad.onshape.com/documents/78aa66ffe6f1daceb9cfad3d/v/746f3ce1b31d39942593ed54/e/92549789b92e9aa35f676f4e")
script_call = BTFeatureScriptEvalCall(script=script)
client = Client()
response = client.part_studios_api.eval_feature_script(element.did,
                                                       element.wvm,
                                                       element.wvmid,
                                                       element.eid,
                                                       bt_feature_script_eval_call=script_call, _preload_content=False)
measurements = json.loads(response.data.decode("utf-8"))["result"]["message"]["value"]
parsed_measurements = {}
for m in measurements:
    key = m["message"]["key"]["message"]["value"]
    value = parse_quantity(m["message"]["value"]["message"])
    parsed_measurements[key] = value
print("Measurements: \n" + str(parsed_measurements))
"""
Measurements: 
{'distance_from_polygon_to_square': '0.1308455707096832*meter', 'diameter': '0.0868175271040671*meter', 'polygon_side_length': '0.05706864859958895*meter'}
"""


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMParameter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'value_object': 'object',
        'revision_data': 'BTRevisionCustomData',
        'configuration_value_string': 'str',
        'direct_imports': 'list[BTMImport]',
        'string_value_for_property': 'str',
        'parameter_id': 'str',
        'changeable_child_field_indices': 'list[int]',
        'for_export': 'bool',
        'import_microversion': 'str',
        'child_nodes': 'dict(str, BTNodeReference)',
        'has_user_code': 'bool',
        'child_locations': 'dict(str, BTInsertionLocation)',
        'source_parse_tree_nodes': 'dict(str, list[BTNodeReference])',
        'node_id': 'str',
        'child_map_indices': 'list[int]',
        'atomic_child_indices': 'list[int]',
        'node_id_raw': 'BTObjectId',
        'first_child_field': 'int',
        'child_list_indices': 'list[int]',
        'type_id': 'int',
        'connection_source': 'BTConnection',
        'export_type_name': 'str',
        'unknown_class': 'bool'
    }

    attribute_map = {
        'value_object': 'valueObject',
        'revision_data': 'revisionData',
        'configuration_value_string': 'configurationValueString',
        'direct_imports': 'directImports',
        'string_value_for_property': 'stringValueForProperty',
        'parameter_id': 'parameterId',
        'changeable_child_field_indices': 'changeableChildFieldIndices',
        'for_export': 'forExport',
        'import_microversion': 'importMicroversion',
        'child_nodes': 'childNodes',
        'has_user_code': 'hasUserCode',
        'child_locations': 'childLocations',
        'source_parse_tree_nodes': 'sourceParseTreeNodes',
        'node_id': 'nodeId',
        'child_map_indices': 'childMapIndices',
        'atomic_child_indices': 'atomicChildIndices',
        'node_id_raw': 'nodeIdRaw',
        'first_child_field': 'firstChildField',
        'child_list_indices': 'childListIndices',
        'type_id': 'typeId',
        'connection_source': 'connectionSource',
        'export_type_name': 'exportTypeName',
        'unknown_class': 'unknownClass'
    }

    def __init__(self, value_object=None, revision_data=None, configuration_value_string=None, direct_imports=None, string_value_for_property=None, parameter_id=None, changeable_child_field_indices=None, for_export=None, import_microversion=None, child_nodes=None, has_user_code=None, child_locations=None, source_parse_tree_nodes=None, node_id=None, child_map_indices=None, atomic_child_indices=None, node_id_raw=None, first_child_field=None, child_list_indices=None, type_id=None, connection_source=None, export_type_name=None, unknown_class=None):  # noqa: E501
        """BTMParameter - a model defined in OpenAPI"""  # noqa: E501

        self._value_object = None
        self._revision_data = None
        self._configuration_value_string = None
        self._direct_imports = None
        self._string_value_for_property = None
        self._parameter_id = None
        self._changeable_child_field_indices = None
        self._for_export = None
        self._import_microversion = None
        self._child_nodes = None
        self._has_user_code = None
        self._child_locations = None
        self._source_parse_tree_nodes = None
        self._node_id = None
        self._child_map_indices = None
        self._atomic_child_indices = None
        self._node_id_raw = None
        self._first_child_field = None
        self._child_list_indices = None
        self._type_id = None
        self._connection_source = None
        self._export_type_name = None
        self._unknown_class = None
        self.discriminator = None

        if value_object is not None:
            self.value_object = value_object
        if revision_data is not None:
            self.revision_data = revision_data
        if configuration_value_string is not None:
            self.configuration_value_string = configuration_value_string
        if direct_imports is not None:
            self.direct_imports = direct_imports
        if string_value_for_property is not None:
            self.string_value_for_property = string_value_for_property
        if parameter_id is not None:
            self.parameter_id = parameter_id
        if changeable_child_field_indices is not None:
            self.changeable_child_field_indices = changeable_child_field_indices
        if for_export is not None:
            self.for_export = for_export
        if import_microversion is not None:
            self.import_microversion = import_microversion
        if child_nodes is not None:
            self.child_nodes = child_nodes
        if has_user_code is not None:
            self.has_user_code = has_user_code
        if child_locations is not None:
            self.child_locations = child_locations
        if source_parse_tree_nodes is not None:
            self.source_parse_tree_nodes = source_parse_tree_nodes
        if node_id is not None:
            self.node_id = node_id
        if child_map_indices is not None:
            self.child_map_indices = child_map_indices
        if atomic_child_indices is not None:
            self.atomic_child_indices = atomic_child_indices
        if node_id_raw is not None:
            self.node_id_raw = node_id_raw
        if first_child_field is not None:
            self.first_child_field = first_child_field
        if child_list_indices is not None:
            self.child_list_indices = child_list_indices
        if type_id is not None:
            self.type_id = type_id
        if connection_source is not None:
            self.connection_source = connection_source
        if export_type_name is not None:
            self.export_type_name = export_type_name
        if unknown_class is not None:
            self.unknown_class = unknown_class

    @property
    def value_object(self):
        """Gets the value_object of this BTMParameter.  # noqa: E501


        :return: The value_object of this BTMParameter.  # noqa: E501
        :rtype: object
        """
        return self._value_object

    @value_object.setter
    def value_object(self, value_object):
        """Sets the value_object of this BTMParameter.


        :param value_object: The value_object of this BTMParameter.  # noqa: E501
        :type: object
        """

        self._value_object = value_object

    @property
    def revision_data(self):
        """Gets the revision_data of this BTMParameter.  # noqa: E501


        :return: The revision_data of this BTMParameter.  # noqa: E501
        :rtype: BTRevisionCustomData
        """
        return self._revision_data

    @revision_data.setter
    def revision_data(self, revision_data):
        """Sets the revision_data of this BTMParameter.


        :param revision_data: The revision_data of this BTMParameter.  # noqa: E501
        :type: BTRevisionCustomData
        """

        self._revision_data = revision_data

    @property
    def configuration_value_string(self):
        """Gets the configuration_value_string of this BTMParameter.  # noqa: E501


        :return: The configuration_value_string of this BTMParameter.  # noqa: E501
        :rtype: str
        """
        return self._configuration_value_string

    @configuration_value_string.setter
    def configuration_value_string(self, configuration_value_string):
        """Sets the configuration_value_string of this BTMParameter.


        :param configuration_value_string: The configuration_value_string of this BTMParameter.  # noqa: E501
        :type: str
        """

        self._configuration_value_string = configuration_value_string

    @property
    def direct_imports(self):
        """Gets the direct_imports of this BTMParameter.  # noqa: E501


        :return: The direct_imports of this BTMParameter.  # noqa: E501
        :rtype: list[BTMImport]
        """
        return self._direct_imports

    @direct_imports.setter
    def direct_imports(self, direct_imports):
        """Sets the direct_imports of this BTMParameter.


        :param direct_imports: The direct_imports of this BTMParameter.  # noqa: E501
        :type: list[BTMImport]
        """

        self._direct_imports = direct_imports

    @property
    def string_value_for_property(self):
        """Gets the string_value_for_property of this BTMParameter.  # noqa: E501


        :return: The string_value_for_property of this BTMParameter.  # noqa: E501
        :rtype: str
        """
        return self._string_value_for_property

    @string_value_for_property.setter
    def string_value_for_property(self, string_value_for_property):
        """Sets the string_value_for_property of this BTMParameter.


        :param string_value_for_property: The string_value_for_property of this BTMParameter.  # noqa: E501
        :type: str
        """

        self._string_value_for_property = string_value_for_property

    @property
    def parameter_id(self):
        """Gets the parameter_id of this BTMParameter.  # noqa: E501


        :return: The parameter_id of this BTMParameter.  # noqa: E501
        :rtype: str
        """
        return self._parameter_id

    @parameter_id.setter
    def parameter_id(self, parameter_id):
        """Sets the parameter_id of this BTMParameter.


        :param parameter_id: The parameter_id of this BTMParameter.  # noqa: E501
        :type: str
        """

        self._parameter_id = parameter_id

    @property
    def changeable_child_field_indices(self):
        """Gets the changeable_child_field_indices of this BTMParameter.  # noqa: E501


        :return: The changeable_child_field_indices of this BTMParameter.  # noqa: E501
        :rtype: list[int]
        """
        return self._changeable_child_field_indices

    @changeable_child_field_indices.setter
    def changeable_child_field_indices(self, changeable_child_field_indices):
        """Sets the changeable_child_field_indices of this BTMParameter.


        :param changeable_child_field_indices: The changeable_child_field_indices of this BTMParameter.  # noqa: E501
        :type: list[int]
        """

        self._changeable_child_field_indices = changeable_child_field_indices

    @property
    def for_export(self):
        """Gets the for_export of this BTMParameter.  # noqa: E501


        :return: The for_export of this BTMParameter.  # noqa: E501
        :rtype: bool
        """
        return self._for_export

    @for_export.setter
    def for_export(self, for_export):
        """Sets the for_export of this BTMParameter.


        :param for_export: The for_export of this BTMParameter.  # noqa: E501
        :type: bool
        """

        self._for_export = for_export

    @property
    def import_microversion(self):
        """Gets the import_microversion of this BTMParameter.  # noqa: E501


        :return: The import_microversion of this BTMParameter.  # noqa: E501
        :rtype: str
        """
        return self._import_microversion

    @import_microversion.setter
    def import_microversion(self, import_microversion):
        """Sets the import_microversion of this BTMParameter.


        :param import_microversion: The import_microversion of this BTMParameter.  # noqa: E501
        :type: str
        """

        self._import_microversion = import_microversion

    @property
    def child_nodes(self):
        """Gets the child_nodes of this BTMParameter.  # noqa: E501


        :return: The child_nodes of this BTMParameter.  # noqa: E501
        :rtype: dict(str, BTNodeReference)
        """
        return self._child_nodes

    @child_nodes.setter
    def child_nodes(self, child_nodes):
        """Sets the child_nodes of this BTMParameter.


        :param child_nodes: The child_nodes of this BTMParameter.  # noqa: E501
        :type: dict(str, BTNodeReference)
        """

        self._child_nodes = child_nodes

    @property
    def has_user_code(self):
        """Gets the has_user_code of this BTMParameter.  # noqa: E501


        :return: The has_user_code of this BTMParameter.  # noqa: E501
        :rtype: bool
        """
        return self._has_user_code

    @has_user_code.setter
    def has_user_code(self, has_user_code):
        """Sets the has_user_code of this BTMParameter.


        :param has_user_code: The has_user_code of this BTMParameter.  # noqa: E501
        :type: bool
        """

        self._has_user_code = has_user_code

    @property
    def child_locations(self):
        """Gets the child_locations of this BTMParameter.  # noqa: E501


        :return: The child_locations of this BTMParameter.  # noqa: E501
        :rtype: dict(str, BTInsertionLocation)
        """
        return self._child_locations

    @child_locations.setter
    def child_locations(self, child_locations):
        """Sets the child_locations of this BTMParameter.


        :param child_locations: The child_locations of this BTMParameter.  # noqa: E501
        :type: dict(str, BTInsertionLocation)
        """

        self._child_locations = child_locations

    @property
    def source_parse_tree_nodes(self):
        """Gets the source_parse_tree_nodes of this BTMParameter.  # noqa: E501


        :return: The source_parse_tree_nodes of this BTMParameter.  # noqa: E501
        :rtype: dict(str, list[BTNodeReference])
        """
        return self._source_parse_tree_nodes

    @source_parse_tree_nodes.setter
    def source_parse_tree_nodes(self, source_parse_tree_nodes):
        """Sets the source_parse_tree_nodes of this BTMParameter.


        :param source_parse_tree_nodes: The source_parse_tree_nodes of this BTMParameter.  # noqa: E501
        :type: dict(str, list[BTNodeReference])
        """

        self._source_parse_tree_nodes = source_parse_tree_nodes

    @property
    def node_id(self):
        """Gets the node_id of this BTMParameter.  # noqa: E501


        :return: The node_id of this BTMParameter.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this BTMParameter.


        :param node_id: The node_id of this BTMParameter.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def child_map_indices(self):
        """Gets the child_map_indices of this BTMParameter.  # noqa: E501


        :return: The child_map_indices of this BTMParameter.  # noqa: E501
        :rtype: list[int]
        """
        return self._child_map_indices

    @child_map_indices.setter
    def child_map_indices(self, child_map_indices):
        """Sets the child_map_indices of this BTMParameter.


        :param child_map_indices: The child_map_indices of this BTMParameter.  # noqa: E501
        :type: list[int]
        """

        self._child_map_indices = child_map_indices

    @property
    def atomic_child_indices(self):
        """Gets the atomic_child_indices of this BTMParameter.  # noqa: E501


        :return: The atomic_child_indices of this BTMParameter.  # noqa: E501
        :rtype: list[int]
        """
        return self._atomic_child_indices

    @atomic_child_indices.setter
    def atomic_child_indices(self, atomic_child_indices):
        """Sets the atomic_child_indices of this BTMParameter.


        :param atomic_child_indices: The atomic_child_indices of this BTMParameter.  # noqa: E501
        :type: list[int]
        """

        self._atomic_child_indices = atomic_child_indices

    @property
    def node_id_raw(self):
        """Gets the node_id_raw of this BTMParameter.  # noqa: E501


        :return: The node_id_raw of this BTMParameter.  # noqa: E501
        :rtype: BTObjectId
        """
        return self._node_id_raw

    @node_id_raw.setter
    def node_id_raw(self, node_id_raw):
        """Sets the node_id_raw of this BTMParameter.


        :param node_id_raw: The node_id_raw of this BTMParameter.  # noqa: E501
        :type: BTObjectId
        """

        self._node_id_raw = node_id_raw

    @property
    def first_child_field(self):
        """Gets the first_child_field of this BTMParameter.  # noqa: E501


        :return: The first_child_field of this BTMParameter.  # noqa: E501
        :rtype: int
        """
        return self._first_child_field

    @first_child_field.setter
    def first_child_field(self, first_child_field):
        """Sets the first_child_field of this BTMParameter.


        :param first_child_field: The first_child_field of this BTMParameter.  # noqa: E501
        :type: int
        """

        self._first_child_field = first_child_field

    @property
    def child_list_indices(self):
        """Gets the child_list_indices of this BTMParameter.  # noqa: E501


        :return: The child_list_indices of this BTMParameter.  # noqa: E501
        :rtype: list[int]
        """
        return self._child_list_indices

    @child_list_indices.setter
    def child_list_indices(self, child_list_indices):
        """Sets the child_list_indices of this BTMParameter.


        :param child_list_indices: The child_list_indices of this BTMParameter.  # noqa: E501
        :type: list[int]
        """

        self._child_list_indices = child_list_indices

    @property
    def type_id(self):
        """Gets the type_id of this BTMParameter.  # noqa: E501


        :return: The type_id of this BTMParameter.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this BTMParameter.


        :param type_id: The type_id of this BTMParameter.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def connection_source(self):
        """Gets the connection_source of this BTMParameter.  # noqa: E501


        :return: The connection_source of this BTMParameter.  # noqa: E501
        :rtype: BTConnection
        """
        return self._connection_source

    @connection_source.setter
    def connection_source(self, connection_source):
        """Sets the connection_source of this BTMParameter.


        :param connection_source: The connection_source of this BTMParameter.  # noqa: E501
        :type: BTConnection
        """

        self._connection_source = connection_source

    @property
    def export_type_name(self):
        """Gets the export_type_name of this BTMParameter.  # noqa: E501


        :return: The export_type_name of this BTMParameter.  # noqa: E501
        :rtype: str
        """
        return self._export_type_name

    @export_type_name.setter
    def export_type_name(self, export_type_name):
        """Sets the export_type_name of this BTMParameter.


        :param export_type_name: The export_type_name of this BTMParameter.  # noqa: E501
        :type: str
        """

        self._export_type_name = export_type_name

    @property
    def unknown_class(self):
        """Gets the unknown_class of this BTMParameter.  # noqa: E501


        :return: The unknown_class of this BTMParameter.  # noqa: E501
        :rtype: bool
        """
        return self._unknown_class

    @unknown_class.setter
    def unknown_class(self, unknown_class):
        """Sets the unknown_class of this BTMParameter.


        :param unknown_class: The unknown_class of this BTMParameter.  # noqa: E501
        :type: bool
        """

        self._unknown_class = unknown_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMParameter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTIdTranslationParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ids': 'list[str]',
        'link_document_id': 'str',
        'source_document_microversion': 'str',
        'source_configuration': 'str',
        'target_configuration': 'str'
    }

    attribute_map = {
        'ids': 'ids',
        'link_document_id': 'linkDocumentId',
        'source_document_microversion': 'sourceDocumentMicroversion',
        'source_configuration': 'sourceConfiguration',
        'target_configuration': 'targetConfiguration'
    }

    def __init__(self, ids=None, link_document_id=None, source_document_microversion=None, source_configuration=None, target_configuration=None):  # noqa: E501
        """BTIdTranslationParams - a model defined in OpenAPI"""  # noqa: E501

        self._ids = None
        self._link_document_id = None
        self._source_document_microversion = None
        self._source_configuration = None
        self._target_configuration = None
        self.discriminator = None

        if ids is not None:
            self.ids = ids
        if link_document_id is not None:
            self.link_document_id = link_document_id
        if source_document_microversion is not None:
            self.source_document_microversion = source_document_microversion
        if source_configuration is not None:
            self.source_configuration = source_configuration
        if target_configuration is not None:
            self.target_configuration = target_configuration

    @property
    def ids(self):
        """Gets the ids of this BTIdTranslationParams.  # noqa: E501


        :return: The ids of this BTIdTranslationParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this BTIdTranslationParams.


        :param ids: The ids of this BTIdTranslationParams.  # noqa: E501
        :type: list[str]
        """

        self._ids = ids

    @property
    def link_document_id(self):
        """Gets the link_document_id of this BTIdTranslationParams.  # noqa: E501


        :return: The link_document_id of this BTIdTranslationParams.  # noqa: E501
        :rtype: str
        """
        return self._link_document_id

    @link_document_id.setter
    def link_document_id(self, link_document_id):
        """Sets the link_document_id of this BTIdTranslationParams.


        :param link_document_id: The link_document_id of this BTIdTranslationParams.  # noqa: E501
        :type: str
        """

        self._link_document_id = link_document_id

    @property
    def source_document_microversion(self):
        """Gets the source_document_microversion of this BTIdTranslationParams.  # noqa: E501


        :return: The source_document_microversion of this BTIdTranslationParams.  # noqa: E501
        :rtype: str
        """
        return self._source_document_microversion

    @source_document_microversion.setter
    def source_document_microversion(self, source_document_microversion):
        """Sets the source_document_microversion of this BTIdTranslationParams.


        :param source_document_microversion: The source_document_microversion of this BTIdTranslationParams.  # noqa: E501
        :type: str
        """

        self._source_document_microversion = source_document_microversion

    @property
    def source_configuration(self):
        """Gets the source_configuration of this BTIdTranslationParams.  # noqa: E501


        :return: The source_configuration of this BTIdTranslationParams.  # noqa: E501
        :rtype: str
        """
        return self._source_configuration

    @source_configuration.setter
    def source_configuration(self, source_configuration):
        """Sets the source_configuration of this BTIdTranslationParams.


        :param source_configuration: The source_configuration of this BTIdTranslationParams.  # noqa: E501
        :type: str
        """

        self._source_configuration = source_configuration

    @property
    def target_configuration(self):
        """Gets the target_configuration of this BTIdTranslationParams.  # noqa: E501


        :return: The target_configuration of this BTIdTranslationParams.  # noqa: E501
        :rtype: str
        """
        return self._target_configuration

    @target_configuration.setter
    def target_configuration(self, target_configuration):
        """Sets the target_configuration of this BTIdTranslationParams.


        :param target_configuration: The target_configuration of this BTIdTranslationParams.  # noqa: E501
        :type: str
        """

        self._target_configuration = target_configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTIdTranslationParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



'''
Export an STL
==============

Demos 307 redirects with the Onshape API
'''

from onshape_client.client import Client
from onshape_client.onshape_url import OnshapeElement, ConfiguredOnshapeElement
from onshape_client.units import u

client = Client()

# Turn the URL into an "OnshapeElement"
url = "https://cad.onshape.com/documents/cca81d10f239db0db9481e6f/v/aaa25d18038e06f0b2964e2d/e/69c9eedda86512966b20bc90"
cube = OnshapeElement(url, client=client)

# get the STL export
stl = client.part_studios_api.export_stl1(cube.did, cube.wvm, cube.wvmid, cube.eid, _preload_content=False)

print("Resulting STL data (unconfigured): \n" + stl.data)

cube = ConfiguredOnshapeElement(url, client=client)
cube.update_current_configuration({'size': 40 * u.inch, 'edge_configuration': 'chamfered'})

# get the STL export
stl = client.part_studios_api.export_stl1(cube.did, cube.wvm, cube.wvmid, cube.eid, configuration=cube.get_configuration_string(), _preload_content=False)

print("Resulting STL data (configured): \n" + stl.data)


from onshape_client.client import Client
import json

class MetaDataBody(object):

    def __init__(self, onshape_element):
        self.body = {'items': []}
        self.onshape_element = onshape_element
        self.__element_property_map = None
        self.__part_property_map = None
        self.__part_index_to_part_id_map = None

    @property
    def element_property_map(self):
        if not self.__element_property_map:
            self.__element_property_map = self.get_element_property_name_to_property_id_map()
        return self.__element_property_map

    @property
    def part_index_to_pid_map(self):
        if not self.__part_index_to_part_id_map:
            self.__part_property_map, self.__part_index_to_part_id_map = self.get_part_property_name_to_property_id_map()
        return self.__part_index_to_part_id_map

    @property
    def part_property_map(self):
        if not self.__part_property_map:
            self.__part_property_map, self.__part_index_to_part_id_map = self.get_part_property_name_to_property_id_map()
        return self.__part_property_map

    def add_to_element_metadata(self, property_name, new_val, eid=None):
        """If needed, can specify other element metadata"""
        try:
            if not eid:
                eid = self.onshape_element.eid
            to_be_appended = {
                    "properties": [
                        {
                            "value": new_val,
                            "propertyId": self.element_property_map[eid][property_name]

                        }
                    ],
                    "href": self.make_element_href(eid)
                }
            self.body['items'].append(to_be_appended)
        except:
            pass

    def add_to_part_metadata(self, property_name, new_val, pid=None, p_index=0):
        """Select part either by pid OR by the part index."""
        try:
            if not pid:
                pid = self.part_index_to_pid_map[p_index]
            to_be_appended = {
                "properties": [
                    {
                        "value": new_val,
                        "propertyId": self.part_property_map[pid][property_name]

                    }
                ],
                "href": self.make_part_href(pid)
            }
            self.body['items'].append(to_be_appended)
        except:
            pass

    def get_element_property_name_to_property_id_map(self):
        """Get the element metadata for the workspace/version and build the map"""
        client = Client.get_client()
        property_map = {}
        response = client.metadata_api.get_wv_es_metadata(self.onshape_element.did, self.onshape_element.wvm, self.onshape_element.wvmid, _preload_content=False)
        data = json.loads(response.data)
        for element in data['items']:
            eid = element['elementId']
            property_map[eid] = {}
            props_to_be_added = property_map[eid]
            for property in element['properties']:
                props_to_be_added[property['name']] = property['propertyId']
        return property_map

    def get_part_property_name_to_property_id_map(self):
        """Get the part property map for the element in the particular version and build out the property map"""
        client = Client.get_client()
        property_map = {}
        part_index_to_part_id = []
        el = self.onshape_element
        response = client.metadata_api.get_wmve_ps_metadata(el.did, el.wvm, el.wvmid, el.eid, _preload_content=False)
        data = json.loads(response.data)
        for i, part in enumerate(data['items']):
            partId = part['partId']
            part_index_to_part_id.append(partId)
            property_map[partId] = {}
            props_to_be_added = property_map[partId]
            for property in part['properties']:
                props_to_be_added[property['name']] = property['propertyId']
        return property_map, part_index_to_part_id

    def make_element_href(self, eid):
        return Client.get_client().configuration.host + "/api/metadata/d/" + self.onshape_element.did + "/" + self.onshape_element.wvm + "/" + self.onshape_element.wvmid + "/e/" + eid

    def make_part_href(self, pid):
        return self.make_element_href(self.onshape_element.eid) + "/p/{}".format(pid)

    def send(self):
        """Update the element metadata as seen fit."""
        self.metadata = Client.get_client().metadata_api.update_wv_metadata(self.onshape_element.did, self.onshape_element.wvm,
                                                               self.onshape_element.wvmid, self.body)

if __name__ == "__main__":
    from onshape_client.onshape_url import OnshapeElement
    element = OnshapeElement(
        "http://localhost.dev.onshape.com:8080/documents/ee93985ceb928f7a7c79fed3/w/593971edd8336a08489ec7c0/e/c066cfbaf68e866b53cdb73f")
    metadata_class = MetaDataBody(element)
    metadata_class.add_to_part_metadata("JHD", "Part number", "my glorious part number")
    metadata_class.send()



from onshape_client.client import Client

def test_specify_client_config_in_code():
    # Clear the current instance if there is one
    Client.__instance = None

    client = Client(configuration={
        "base_url": "https://cad.onshape.com",
        "access_key": "USER_ACCESS_KEY",
        "secret_key": "USER_SECRET_KEY"
    })

    assert client.configuration.api_key["SECRET_KEY"] == "USER_SECRET_KEY"
    assert client.configuration.api_key["ACCESS_KEY"] == "USER_ACCESS_KEY"


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class CloudObjectPathSegment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cloud_storage_account_id': 'str',
        'cloud_storage_provider_type': 'int',
        'name': 'str',
        'id': 'str',
        'tree_href': 'str',
        'resource_type': 'str',
        'sub_type': 'int'
    }

    attribute_map = {
        'cloud_storage_account_id': 'cloudStorageAccountId',
        'cloud_storage_provider_type': 'cloudStorageProviderType',
        'name': 'name',
        'id': 'id',
        'tree_href': 'treeHref',
        'resource_type': 'resourceType',
        'sub_type': 'subType'
    }

    def __init__(self, cloud_storage_account_id=None, cloud_storage_provider_type=None, name=None, id=None, tree_href=None, resource_type=None, sub_type=None):  # noqa: E501
        """CloudObjectPathSegment - a model defined in OpenAPI"""  # noqa: E501

        self._cloud_storage_account_id = None
        self._cloud_storage_provider_type = None
        self._name = None
        self._id = None
        self._tree_href = None
        self._resource_type = None
        self._sub_type = None
        self.discriminator = None

        if cloud_storage_account_id is not None:
            self.cloud_storage_account_id = cloud_storage_account_id
        if cloud_storage_provider_type is not None:
            self.cloud_storage_provider_type = cloud_storage_provider_type
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if tree_href is not None:
            self.tree_href = tree_href
        if resource_type is not None:
            self.resource_type = resource_type
        if sub_type is not None:
            self.sub_type = sub_type

    @property
    def cloud_storage_account_id(self):
        """Gets the cloud_storage_account_id of this CloudObjectPathSegment.  # noqa: E501


        :return: The cloud_storage_account_id of this CloudObjectPathSegment.  # noqa: E501
        :rtype: str
        """
        return self._cloud_storage_account_id

    @cloud_storage_account_id.setter
    def cloud_storage_account_id(self, cloud_storage_account_id):
        """Sets the cloud_storage_account_id of this CloudObjectPathSegment.


        :param cloud_storage_account_id: The cloud_storage_account_id of this CloudObjectPathSegment.  # noqa: E501
        :type: str
        """

        self._cloud_storage_account_id = cloud_storage_account_id

    @property
    def cloud_storage_provider_type(self):
        """Gets the cloud_storage_provider_type of this CloudObjectPathSegment.  # noqa: E501


        :return: The cloud_storage_provider_type of this CloudObjectPathSegment.  # noqa: E501
        :rtype: int
        """
        return self._cloud_storage_provider_type

    @cloud_storage_provider_type.setter
    def cloud_storage_provider_type(self, cloud_storage_provider_type):
        """Sets the cloud_storage_provider_type of this CloudObjectPathSegment.


        :param cloud_storage_provider_type: The cloud_storage_provider_type of this CloudObjectPathSegment.  # noqa: E501
        :type: int
        """

        self._cloud_storage_provider_type = cloud_storage_provider_type

    @property
    def name(self):
        """Gets the name of this CloudObjectPathSegment.  # noqa: E501


        :return: The name of this CloudObjectPathSegment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CloudObjectPathSegment.


        :param name: The name of this CloudObjectPathSegment.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this CloudObjectPathSegment.  # noqa: E501


        :return: The id of this CloudObjectPathSegment.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CloudObjectPathSegment.


        :param id: The id of this CloudObjectPathSegment.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def tree_href(self):
        """Gets the tree_href of this CloudObjectPathSegment.  # noqa: E501


        :return: The tree_href of this CloudObjectPathSegment.  # noqa: E501
        :rtype: str
        """
        return self._tree_href

    @tree_href.setter
    def tree_href(self, tree_href):
        """Sets the tree_href of this CloudObjectPathSegment.


        :param tree_href: The tree_href of this CloudObjectPathSegment.  # noqa: E501
        :type: str
        """

        self._tree_href = tree_href

    @property
    def resource_type(self):
        """Gets the resource_type of this CloudObjectPathSegment.  # noqa: E501


        :return: The resource_type of this CloudObjectPathSegment.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this CloudObjectPathSegment.


        :param resource_type: The resource_type of this CloudObjectPathSegment.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def sub_type(self):
        """Gets the sub_type of this CloudObjectPathSegment.  # noqa: E501


        :return: The sub_type of this CloudObjectPathSegment.  # noqa: E501
        :rtype: int
        """
        return self._sub_type

    @sub_type.setter
    def sub_type(self, sub_type):
        """Sets the sub_type of this CloudObjectPathSegment.


        :param sub_type: The sub_type of this CloudObjectPathSegment.  # noqa: E501
        :type: int
        """

        self._sub_type = sub_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudObjectPathSegment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



'''
importstl
===

Demos importing an STL file
'''

from onshape_client.client import Client
from onshape_client.onshape_url import OnshapeElement
from onshape_client.utility import get_field
import os
import time

def import_file(file_path, did, wid):
    """Import a file from the local file system. Returns the URL of the resulting element if translated."""
    client = Client.get_client()
    file = open(file_path, 'r').read()
    r = client.blob_elements_api.upload_file_create_element(did, wid, media_type="application/stl", file=file, translate=True, encodedFilename=file_path.split('/')[-1], _preload_content=False)
    translation_id = get_field(r, 'translationId')
    print("The translationId is: {}.".format(translation_id))

    state = 'ACTIVE'
    while state == 'ACTIVE':
        time.sleep(2)
        r = client.translation_api.get_translation(translation_id, _preload_content=False)
        state = get_field(r, "requestState")

    element_id = get_field(r, 'resultElementIds')[0]
    # Make the actual download when the translation is done, otherwise report the error
    if state == "DONE":
        print("Translated document available at {host}/documents/{did}/w/{wid}/e/{eid}".format(host=client.configuration.host,
                                                                                did=get_field(r, 'documentId'),
                                                                                wid=get_field(r, 'workspaceId'),
                                                                                eid=element_id))
    else:
        print("An error ocurred on the server! Here is the response: \n")
    return element_id

if __name__ == "__main__":
    element = OnshapeElement(
        "http://localhost.dev.onshape.com:8080/documents/ee93985ceb928f7a7c79fed3/w/593971edd8336a08489ec7c0/e/c066cfbaf68e866b53cdb73f")
    import_file(os.path.dirname(__file__) + "/assets/Cube.x_t", element.did, element.wvmid)


from onshape_client.client import Client, OAuthAuthorizationMethods

client = Client(stack_key="prod-oauth-full")

def test_client(configurable_cube):
    call_api(configurable_cube, client)

def test_manual_oauth_flow(configurable_cube):
    client.oauth_authorization_method = OAuthAuthorizationMethods.MANUAL_FLOW
    # save refresh token then put in later.
    refresh_token = client.refresh_token
    client.refresh_token = ""
    client.configuration.access_token = ""
    try:
        call_api(configurable_cube, client)
    except Exception as e:
        client.refresh_token = refresh_token
        call_api(configurable_cube, client)


def call_api(cube, client):
    client.elements_api.get_configuration3(cube.did, cube.wvm, cube.wvmid, cube.eid)


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTUserUsagesSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'count': 'int',
        'owner_id': 'str',
        'owner_type': 'str',
        'owner_name': 'str'
    }

    attribute_map = {
        'count': 'count',
        'owner_id': 'ownerId',
        'owner_type': 'ownerType',
        'owner_name': 'ownerName'
    }

    def __init__(self, count=None, owner_id=None, owner_type=None, owner_name=None):  # noqa: E501
        """BTUserUsagesSummary - a model defined in OpenAPI"""  # noqa: E501

        self._count = None
        self._owner_id = None
        self._owner_type = None
        self._owner_name = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if owner_id is not None:
            self.owner_id = owner_id
        if owner_type is not None:
            self.owner_type = owner_type
        if owner_name is not None:
            self.owner_name = owner_name

    @property
    def count(self):
        """Gets the count of this BTUserUsagesSummary.  # noqa: E501


        :return: The count of this BTUserUsagesSummary.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this BTUserUsagesSummary.


        :param count: The count of this BTUserUsagesSummary.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def owner_id(self):
        """Gets the owner_id of this BTUserUsagesSummary.  # noqa: E501


        :return: The owner_id of this BTUserUsagesSummary.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTUserUsagesSummary.


        :param owner_id: The owner_id of this BTUserUsagesSummary.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def owner_type(self):
        """Gets the owner_type of this BTUserUsagesSummary.  # noqa: E501


        :return: The owner_type of this BTUserUsagesSummary.  # noqa: E501
        :rtype: str
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """Sets the owner_type of this BTUserUsagesSummary.


        :param owner_type: The owner_type of this BTUserUsagesSummary.  # noqa: E501
        :type: str
        """

        self._owner_type = owner_type

    @property
    def owner_name(self):
        """Gets the owner_name of this BTUserUsagesSummary.  # noqa: E501


        :return: The owner_name of this BTUserUsagesSummary.  # noqa: E501
        :rtype: str
        """
        return self._owner_name

    @owner_name.setter
    def owner_name(self, owner_name):
        """Sets the owner_name of this BTUserUsagesSummary.


        :param owner_name: The owner_name of this BTUserUsagesSummary.  # noqa: E501
        :type: str
        """

        self._owner_name = owner_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTUserUsagesSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.api_client import ApiClient


class DrawingsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_translator_formats2(self, did, wid, eid, **kwargs):  # noqa: E501
        """get_translator_formats2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translator_formats2(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_translator_formats2_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_translator_formats2_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
            return data

    def get_translator_formats2_with_http_info(self, did, wid, eid, **kwargs):  # noqa: E501
        """get_translator_formats2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translator_formats2_with_http_info(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'eid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_translator_formats2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_translator_formats2`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `get_translator_formats2`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_translator_formats2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/drawings/d/{did}/w/{wid}/e/{eid}/translationformats', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translate_format4(self, did, wv, wvid, eid, bt_translate_format_params, **kwargs):  # noqa: E501
        """Create Drawing translation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate_format4(did, wv, wvid, eid, bt_translate_format_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param BTTranslateFormatParams bt_translate_format_params: (required)
        :return: BTTranslationRequestInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.translate_format4_with_http_info(did, wv, wvid, eid, bt_translate_format_params, **kwargs)  # noqa: E501
        else:
            (data) = self.translate_format4_with_http_info(did, wv, wvid, eid, bt_translate_format_params, **kwargs)  # noqa: E501
            return data

    def translate_format4_with_http_info(self, did, wv, wvid, eid, bt_translate_format_params, **kwargs):  # noqa: E501
        """Create Drawing translation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate_format4_with_http_info(did, wv, wvid, eid, bt_translate_format_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param BTTranslateFormatParams bt_translate_format_params: (required)
        :return: BTTranslationRequestInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wv', 'wvid', 'eid', 'bt_translate_format_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translate_format4" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `translate_format4`")  # noqa: E501
        # verify the required parameter 'wv' is set
        if ('wv' not in local_var_params or
                local_var_params['wv'] is None):
            raise ValueError("Missing the required parameter `wv` when calling `translate_format4`")  # noqa: E501
        # verify the required parameter 'wvid' is set
        if ('wvid' not in local_var_params or
                local_var_params['wvid'] is None):
            raise ValueError("Missing the required parameter `wvid` when calling `translate_format4`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `translate_format4`")  # noqa: E501
        # verify the required parameter 'bt_translate_format_params' is set
        if ('bt_translate_format_params' not in local_var_params or
                local_var_params['bt_translate_format_params'] is None):
            raise ValueError("Missing the required parameter `bt_translate_format_params` when calling `translate_format4`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wv' in local_var_params:
            path_params['wv'] = local_var_params['wv']  # noqa: E501
        if 'wvid' in local_var_params:
            path_params['wvid'] = local_var_params['wvid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_translate_format_params' in local_var_params:
            body_params = local_var_params['bt_translate_format_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/drawings/d/{did}/{wv}/{wvid}/e/{eid}/translations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTTranslationRequestInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
